@@ -46,10 +46,23 @@ class PluginValues(Base):
         return NickNames.__str__(self)
 
 
+class Welcome(Base):
+    __tablename__ = 'welcome'
+    welcome_id = Column(Integer, primary_key=True)
+    nick_id = Column(Integer)
+    account = Column(String)
+    channel = Column(String)
+    timestamp = Column(String)
+    message = Column(String)
+
+    def __str__(self):
+        return Welcome.__str__(self)
+
+
 if __name__ == '__main__':
     try:
         engine = create_engine('sqlite:///{0}'.format(sys.argv[1]), echo=True)
     except IndexError:
         print('argument not provided')
-        engine = create_engine('sqlite:///hasan2.db', echo=True)
+        engine = create_engine('sqlite:///example-model.db', echo=True)
     Base.metadata.create_all(engine)
