@@ -1,9 +1,11 @@
-import models
-from sqlalchemy import create_engine
 import os
 import re
 import sqlite3
 import sys
+
+import models
+from sqlalchemy import create_engine
+
 PATH = '../MirahezeBots/MirahezeBots'
 PLUGINPATH = '../MirahezeBots/MirahezeBots/plugins'
 sys.path.append(PATH)
@@ -11,17 +13,17 @@ sys.path.append(PATH)
 
 def test_db_schema_is_same():
     original, new = set(), set()  # noqa: F841
-    with sqlite3.connect(os.path.join(PATH, 'hasan.db')) as conn:
+    with sqlite3.connect(os.path.join(PATH, 'example.db')) as conn:
         conn.text_factory = str
         res = conn.execute("SELECT name FROM sqlite_master WHERE type='table';")
         [original.add(tbl[0]) for tbl in res if not tbl[0] == 'nick_ids' and not tbl[0] == 'sqlite_sequence']
 
     try:
-        os.unlink(os.path.join(PATH, "hasan2.db"))
+        os.unlink(os.path.join(PATH, "example-model.db"))
     except FileNotFoundError:
         pass
 
-    engine = create_engine('sqlite:///{0}'.format(os.path.join(PATH, "..", "hasan2.db")))
+    engine = create_engine('sqlite:///{0}'.format(os.path.join(PATH, "..", "example-model.db")))
     models.Base.metadata.create_all(bind=engine)
     assert original == set(engine.table_names())
 
