@@ -1,5 +1,4 @@
-from MirahezeBots.utils import jsonparser as jp
-
+from MirahezeBots_jsonparser import jsonparser as jp
 
 DICT = {'#miraheze-cvt-private': {'inherits-from': ['#miraheze-cvt']}, '#miraheze-cvt': {'chanops': ['NDKilla', 'Voidwalker', 'Reception123', 'The_Pionner', 'JohnLewis', 'Zppix']}}
 
